import {Component} from "@angular/core";

@Component({
    selector: 'plugin-branch',
    templateUrl: 'branch.component.mweb.html',
    moduleId: module.id
})
export class BranchComponent {

    constructor() {

    }

}
